
local indexing = {
	['k'] = math.pow(10, 3),
	['K'] = math.pow(10, 3),
	['M'] = math.pow(10, 6),
	['G'] = math.pow(10, 9),
	['T'] = math.pow(10, 12),
	['P'] = math.pow(10, 15),
	['E'] = math.pow(10, 18),
	['Z'] = math.pow(10, 21),
	['Y'] = math.pow(10, 24),
}

local function convert(units)
	local power = tonumber(units)
	local watts = false

	if not power then
		power = tonumber(units:sub(1, -2))
		watts = true
	end

	if not power then
		power = tonumber(units:sub(1, -3)) * (indexing[units:sub(-2, -2)] or 1)
	end

	return power, watts
end

local function slot_mult(value)
	if value == 0 then return 0 end

	return math.max(1, math.ceil(value * settings.startup['personal-roboport-tweaker-power-capacity'].value - 0.5))
end

for index, value in pairs(data.raw['roboport-equipment']) do
	if value.burner and value.power then
		if type(value.burner.fuel_inventory_size) == 'number' then
			value.burner.fuel_inventory_size = slot_mult(value.burner.fuel_inventory_size)
		end

		local _value, watts = convert(value.power)

		if watts then
			value.power = (_value * settings.startup['personal-roboport-tweaker-power-capacity'].value) .. 'J'
		else
			value.power = (_value * settings.startup['personal-roboport-tweaker-power-capacity'].value)
		end
	elseif value.energy_source and value.energy_source.type == 'electric' then
		local _value, watts = convert(value.energy_source.buffer_capacity)

		if watts then
			value.energy_source.buffer_capacity = (_value * settings.startup['personal-roboport-tweaker-power-capacity'].value) .. 'J'
		else
			value.energy_source.buffer_capacity = (_value * settings.startup['personal-roboport-tweaker-power-capacity'].value)
		end

		if value.charging_energy then
			_value, watts = convert(value.charging_energy)

			if watts then
				value.charging_energy = (_value * settings.startup['personal-roboport-tweaker-charge-flow'].value) .. 'W'
			else
				value.charging_energy = (_value * settings.startup['personal-roboport-tweaker-charge-flow'].value)
			end
		end

		if value.energy_source.input_flow_limit then
			_value, watts = convert(value.energy_source.input_flow_limit)

			if watts then
				value.energy_source.input_flow_limit = (_value * settings.startup['personal-roboport-tweaker-power-flow'].value) .. 'W'
			else
				value.energy_source.input_flow_limit = (_value * settings.startup['personal-roboport-tweaker-power-flow'].value)
			end
		end

		if value.energy_source.output_flow_limit then
			_value, watts = convert(value.energy_source.output_flow_limit)

			if watts then
				value.energy_source.output_flow_limit = (_value * settings.startup['personal-roboport-tweaker-power-flow'].value) .. 'W'
			else
				value.energy_source.output_flow_limit = (_value * settings.startup['personal-roboport-tweaker-power-flow'].value)
			end
		end

		if value.robot_limit then
			value.robot_limit = math.max(1, math.ceil(value.robot_limit * settings.startup['personal-roboport-tweaker-work-slot-count'].value - 0.5))
		end

		if value.charging_station_count and value.charging_station_count > 0 then
			value.charging_station_count = math.max(1, math.ceil(value.charging_station_count * settings.startup['personal-roboport-tweaker-charge-slot-count'].value - 0.5))
		end
	end
end
